#
# spec file for package liblxqt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           liblxqt
Version:        2.1.0
Release:        1.3
Summary:        Core utility library for LXQt
License:        LGPL-2.1-or-later
URL:            https://github.com/lxqt/liblxqt
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem) >= 6.0.0
BuildRequires:  cmake(PolkitQt6-1) >= 0.200.0
BuildRequires:  cmake(Qt6DBus) >= 6.6
BuildRequires:  cmake(Qt6LinguistTools) >= 6.6
BuildRequires:  cmake(Qt6Widgets) >= 6.6
BuildRequires:  cmake(lxqt2-build-tools) >= 2.1.0
BuildRequires:  pkgconfig(Qt6Xdg) >= 4.1.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xscrnsaver)
Obsoletes:      liblxqt-qt5 < %{version}
Provides:       liblxqt-qt5 = %{version}
# moved files to correct location in liblxqt1 (/lxqt-backlight_backend, power.conf, polkit)
Conflicts:      liblxqt0
Conflicts:      liblxqt1
Requires:       /usr/bin/pkexec

%description
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

%lang_package

%package -n %{name}2
Summary:        LXQt core library
Recommends:     %{name}-lang
Requires:       %{name} >= %{version}

%description -n %{name}2
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

%package devel
Summary:        Devel files for liblxqt
Requires:       %{name}2 = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(Qt6Xdg) >= 4.1.0

%description devel
liblxqt represents the core library of LXQt providing essential
functionality needed by nearly all of its components.

This subpackage contains libraries and header files for developing
applications that want to make use of liblxqt.

%prep
%autosetup -p1

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}

%find_lang %{name} --with-qt

%ldconfig_scriptlets -n %{name}2

%files
%dir %{_datadir}/lxqt/
%{_datadir}/lxqt/power.conf
%{_bindir}/lxqt-backlight_backend
%dir %{_datadir}/polkit-1/
%{_datadir}/polkit-1/actions/

%files -n %{name}2
%license COPYING
%doc AUTHORS
%{_qt6_libdir}/%{name}.so.?
%{_qt6_libdir}/%{name}.so.?.*

%files devel
%{_includedir}/lxqt/
%{_qt6_libdir}/pkgconfig/lxqt.pc
%{_qt6_libdir}/%{name}.so
%{_datadir}/cmake/lxqt/

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/%{name}
%if 0%{?sle_version}
%{_datadir}/lxqt/translations/%{name}/%{name}_???.qm
%endif

%changelog
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#354)
  * Support reversing the order of items in LXQt's grid layout (#353)
  * Fixed setting of item geometries in grid layout (#351)
  * weblate commits (#350)
  * weblate commits (#348)
  * Enable custom screenlockers on X11 and wayland (#346)
  * Replaced `QLatin1String` with `QLatin1StringView` (#347)
  * weblate commits (#345)
  * Pre-release changes (#344)
  * Update some minimum required versions (#343)
* Wed Apr 17 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6
- Specfile cleanup and macro updates
* Fri Jan 12 2024 Shawn Dunn <sfalken@opensuse.org>
- Changes to fix (boo#1218288)
  * Removed Provides: and Recommends: from liblxqt1 subpackage
  * Added Requires: liblxqt >= version to liblxqt1 subpackage
* Sun Nov  5 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.4.0:
  * Deprecated KWindowSystem methods are ported.
  * Show error on trying to lock screen under Wayland.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Updated translations and bumped version to 1.3.0
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Updated translations and bumped version to 1.2.0
* Wed Aug  3 2022 Michael Vetter <mvetter@suse.com>
- Require /usr/bin/pkexec instead of pkexec to not depend on
  a certain package
* Mon Jul 18 2022 Marcus Meissner <meissner@suse.com>
- require pkexec as its now a standalone package
* Wed Apr 27 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Added support for relative wallpaper paths.
  * Fixed an issue in loading of cached settings.
* Fri Nov  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped version to 1.0.0 and required Qt 5.15.0.
- Move into main package liblxqt:
  * /usr/share/lxqt/power.conf
  * /usr/bin/lxqt-backlight_backend
  * /usr/share/polkit-1/actions/org.lxqt.backlight.pkexec.policy
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Fixed dbus errors with invalid QVariant data sent over it.
  * Modernized and cleaned up the code.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Remove deprecated recommends on lang package
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Use QFlags default constructor
  * Added an action for showing LXQt leave dialog
    (to be used when the power button is pressed).
  * Don't use deprecated QProcess methods.
* Fri May 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * Fix a crash on closing screen saver error message.
  * Let Qt handle the positions of dialogs (in that way, dialogs
    are shown on the correct screen).
  * Remove dead codes.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed liblxqt.keyring to tsujan's key
* Fri Apr 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Removed liblxqt-0.14.1-fix-qt-5.14.patch: contained in upstream
- Update to version 0.15.0
  * Fixed memory leak in backlight brightness driver.
  * Allowed custom lock command and improved error messages in lxqtscreensaver.
  * Added asynchronous API for querying server info.
  * Allow spacing to be added between items in GridLayout (used in lxqt-panel).
  * Set default button to Yes in leave dialogs.
  * Made macOS build possible.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Add includes for QFile
- Add liblxqt-0.14.1-fix-qt-5.14.patch
* Mon Feb 25 2019 mvetter@suse.com
- Update to 0.14.1:
  * Bumped version to 0.14.1
  * Enable/disable a standard button if it exists. This is needed for adding
    Apply button later because Apply button should be enabled/disabled
    appropriately.
  * Updated translations
  * Note for packagers: liblxqt now depend on libqtxdg 3.3.1
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Added missing text color of our HTML delegate
  * lxqtbacklight: fix and improve command line parameter handling
  * lxqthtmldelegate: Position, alignment and size fixes for HTML delegate
  * lxqtpageselectwidget: Fix config dialog cell height
  * lxqtpageselectwidget: Fixed config dialog select widget cells
- Remove liblxqt-0.13.0-backlight.patch: upstreamed
- Move translation from lxqt-l10n into package
* Wed Jun 20 2018 mvetter@suse.com
- Update liblxqt-0.13.0-backlight.patch: use accepted one
* Thu Jun 14 2018 mvetter@suse.com
- Remove liblxqt-rpmlintrc (See bsc#1092192)
- Add liblxqt-0.13.0-backlight.patch:
  Created by mgerstner when auditing.
  See https://github.com/lxqt/liblxqt/pull/148
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * An efficient backlight control is added.
  * ConfigDialog: Adds the ability to select the shown page by name
  * lxqtpower: Add support for turning monitor(s) off
- Add BuildRequires for polkit-qt5-1
- Add lxqt-backlight_backend and polkit file
- Add rpmlintrc exception (bsc#1092192)
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Bump minimum qtxdg version to 3.1.0
  * Don't export github templates
  * Bump version and needed versions to the final values
  * lxqtpower: Allow disabling of lxqt-session provider
  * Drops Qt5Core_VERSION_STRING
  * HtmlDelegate: Fix sizeHint() computation
  * Add some comments about the meaning of versions
  * Move LXQt version back to liblxqt
  * Fixes (#118)
  * lxqtapplication: Avoid wrong signal handling
  * Removes unneeded semicolon in namespace definition
  * Fix format conversions [-Wformat-pedantic] warnings
  * Suppress compiler warnings about unused function parameters
  * Removes extra semicolons in Qt's Q macros
  * Translator: Prefer XDG_DATA_DIRS over compiled in path
  * Help the compiler optimizing loops
  * Use const variables where possible
  * Update AUTHORS
- Remove liblxqt-0.11.1-allow-disabl-lxqt-session.patch:
  contained in upstream
* Wed Sep 13 2017 mvetter@suse.com
- boo#1044483:
  * Add liblxqt-0.11.1-allow-disabl-lxqt-session.patch
    to allow disabling of lxqt-session
* Thu Feb 23 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Bump needed build tools version (#113)
  * build: Enable/disable WITH_XDG_DIRS_FALLBACK based on Qt version (#111)
  * Updates lxqt-build-tools required version
  * Adds a CMake minimum version requirement to the -config.cmake
  * Refactors superbuild support
  * Adds PROJECT_NAME to the build with Qt version message
  * Pack target_compile_definitions() and target_include_directories()
  * Adds PROJECT_NAME to the build with Qt version message
  * Pack target_compile_definitions() and target_include_directories()
  * Use the LXQtConfigVars module
  * Make liblxqt depend on lxqt-build-tools
  * Use the lxqt-build-tools LXQtCreatePortableHeaders
  * Use the new LXQt Build Tools package
  * Sets a minimum Qt5Xdg required version
  * Adds minimum Qt version requirement (5.4.2)
  * Remove cpack (#107)
* Fri Sep 30 2016 jengelh@inai.de
- Update descriptions. Drop seemingly unneeded Provides: liblxqt.
  Own all directories.
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Bump version ot 0.11.0 (#105)
  * Settings: Make use of reverse_iterator conditional
  * Application: Add <cerrno> include
  * Settings: Add "homemade" XDG_CONFIG_DIRS support
  * Settings: unify duplicated code
  * Add README.md
  * translations: Change default translations repository
  * Update DBus Notify method annotation name
  * Fix lupdate warning missing Q_OBJECT macro
  * Replaces deprecated QStyleOptionViewItemV4
  * Don't lock the screen when it's already locked.
  * lxqtscreensaver: Makes it a opaque pointer class
  * GridLayout: Store current animation flag
  * lxqtgridlayout: Move private class definition
  * HtmlDelegate: Take layoutDirection into account
  * GridLayout: Take layoutDirection into account
  * application: Correct signal handling & clean-up (#72)
  * lxqtpower: Removes unused stuff
  * SingleApplication: Only create an DBus adaptor when needed
  * NotificationPrivate: Fixes programming typo
  * Don't set icon theme name
  * configdialog: Update icons in ThemeChanged event
  * lxqtpower: Add suspend and hibernate to ConsoleKit2 provider
  * LXQtTranslateTs.cmake: Enable PULL_TRANSLATIONS by default
  * LXQtTranslateTs.cmake: Use/update template in remote repo
  * .gitignore: Cleanup
  * build: Use external translations
  * ts-files removal (#90)
  * GridLayout: Fix memory leak
  * translations: Fix external translations logic
  * translations: Add external translations support
  * configdialog: Fix icon bar sizing
  * configdialog: fix size of PageSelectWidget (#83)
  * Use const references with the foreach iterator
  * SettingsCache: Improve performance
  * Print warning messages when using the fallback Icon Theme
  * Use LXQT_DATA_DIR for fallback icon theme search path
  * Sets Oxygen as the only fallback icon theme
  * Adds CMAKE_INSTALL_PREFIX to the LXQt Theme search paths
  * LXQtCompilerSettings: Add QT_USE_QSTRINGBUILDER to the compile definitions
  * SingleApplication: Use QCoreApplication::exit() instead of ::exit()
  * bump year
  * TranslateDesktopTs: Adds UPDATE_OPTIONS options
  * TranslateDesktop: Remove lupdate absolute option
  * TranslateDesktop: Use -a switch in grep commands
  * LXQtTheme: Remove (outdated) "singleclick" qss assembly
  * settings: Upgrade emitting of "changed" signals
  * SingleApplication: Call also QWidget::show on activate
  * Updated Russian translation Removed ru_RU file
  * Use QString() instead of ""
  * Use CMAKE_INSTALL_FULL_DATAROOTDIR
  * Add LXQT_GRAPHICS_DIR directory definition
  * lxqt-config: Correct escaping while setting variables
  * CMake: Removes artifact
  * Adds FindXdgUserDirs CMake find_package module
  * Italian translation update
* Tue Nov 10 2015 mvetter@suse.com
- Remove patch 0001-fix-build-with-qt-5.5.patch
  Contained in upstream version
* Thu Nov  5 2015 mvetter@suse.com
- Upstream release 0.10.0
* Thu Oct  8 2015 mvetter@suse.com
- Factory moved fom libqt5.4 to 5.5
  0001-fix-build-with-qt-5.5.patch: include QObject header explicitly
* Thu Jul  9 2015 mvetter@suse.com
- Use correct name "lxqt" instead of "lxde-qt"
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed to %%cmake and %%cmake_install macros in %%build and
  %%install
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Dropped -qt5 package naming, as none of the internal library
  names use -qt5 in 0.9.0.  Added Obsoletes and Conflicts, in the
  odd chance that liblxqt-0.7.0 and liblxqt >=0.8.0 are installed
  on the same system.  Which should never happen.  lxqt-0.9.0 is not
  likely to be pushed to 13.2, and liblxqt can no longer be built
  against Qt4.
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to build for Fedora
* Fri Oct 24 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up
* Tue May 13 2014 sfalken@opensuse.org
- Cleaned up BuildRequires:
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora spec, split into seperate subproject
  Del: liblxqt-Fedora_20.spec
* Sun May 11 2014 sfalken@opensuse.org
- Removed BuildRequires: pkgconfig entries in favour of BuildRequires: libqt4-devel at request of X11:lxde:lxqt maintainers
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: liblxqt-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add: liblxqt-0.7.0.tar.xz
  Del: _service
* Thu Apr 17 2014 sfalken@opensuse.org
- Shortened Summary: to make rpmlint happy
  Removed explicit Requires: per rpmlint
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct calls to cmake, in favour of %%cmake and %%cmake_install macros
* Wed Apr  2 2014 sfalken@opensuse.org
- Specfile finalized
* Wed Apr  2 2014 sfalken@opensuse.org
- Inital Source Upload
  Add:  _service
  Add:  liblxqt.spec
  Add:  liblxqt.changes
